@@ -31,7 +31,7 @@ from neo4jrestclient.exceptions import (NotFoundError, StatusException,
                                         TransactionException)
 from neo4jrestclient.traversals import TraversalDescription, GraphTraversal
 from neo4jrestclient.utils import (PY2, text_type, smart_quote, string_types,
-                                   unquote)
+                                   unquote, get_auth_from_uri)
 
 __all__ = ["GraphDatabase", "Incoming", "Outgoing", "Undirected",
            "StopAtDepth", "NotFoundError", "StatusException", "Q"]
@@ -56,6 +56,9 @@ class GraphDatabase(object):
 
     def __init__(self, url, username=None, password=None, cert_file=None,
                  key_file=None):
+        username_uri, password_uri, xxx = get_auth_from_uri(url)
+        username = username or username_uri
+        password = password or password_uri
         self._auth = {
             "username": username,
             "password": password,
@@ -2214,6 +2217,24 @@ class ExtensionsProxy(dict):
             self._dict = self._get_dict()
         return self._dict.keys()
 
+    # Special methods for handle pickling manually
+    def __getnewargs__(self):
+        return tuple()
+
+    def __getstate__(self):
+        data = {}
+        for key, value in self.__dict__.items():
+            try:
+                encoded = pickle.dumps(value)
+            except pickle.PicklingError:
+                encoded = pickle.dumps(pickle.Unpickable())
+            data[key] = encoded
+        return data
+
+    def __setstate__(self, state):
+        for key, value in state.items():
+            self.__dict__[key] = pickle.loads(value)
+
 
 class Extension(object):
     """
