@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 __author__ = "Javier de la Rosa"
 __license__ = "GPL 3"
-__version__ = "2.0.2"
+__version__ = "2.0.3"
 __email__ = "versae@gmail.com"
 __url__ = "https://github.com/versae/neo4j-rest-client"
 __description__ = """Object-oriented Python library to interact with """ \
                   """Neo4j standalone REST server"""
-__status__ = "Development"
+__status__ = "Stable"
 # Order
 BREADTH_FIRST = "breadth_first"
 DEPTH_FIRST = "depth_first"
